@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # Copyright (c) 2016 mindsensors.com
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#mindsensors.com invests time and resources providing this open source code, 
+#mindsensors.com invests time and resources providing this open source code,
 #please support mindsensors.com  by purchasing products from mindsensors.com!
 #Learn more product option visit us @  http://www.mindsensors.com/
 #
@@ -25,7 +25,6 @@
 #
 
 from PiStorms import PiStorms
-print "running program"
 psm = PiStorms()
 
 m = ["Motor-Demo", "Connect motor to Bank A M1.",
@@ -34,8 +33,8 @@ m = ["Motor-Demo", "Connect motor to Bank A M1.",
   "Click OK to continue"]
 psm.screen.askQuestion(m,["OK"])
 
-# run motor for 360 degrees, and at the completion, 
-# brake while stopping 
+# run motor for 360 degrees, and at the completion,
+# brake while stopping
 psm.BAM1.runDegs(360, 75, True, False)
 
 m = ["Motor-Demo", "Motor should have turned 360 degrees",
