@@ -1,10 +1,6 @@
 <?php
 include "config.php";
 
-if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
-    die();
-}
-
 $zip = new ZipArchive;
 $download = 'screenshots_export.zip';
 $zip->open($download, ZipArchive::CREATE);
@@ -16,4 +12,4 @@ header('Content-Type: application/zip');
 header("Content-Disposition: attachment; filename = $download");
 header('Content-Length: ' . filesize($download));
 //header("Location: $download");
-?>
\ No newline at end of file
+?>
