@@ -1,7 +1,7 @@
 <?php
 /*
 # Copyright (c) 2016 mindsensors.com
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
@@ -15,23 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-#mindsensors.com invests time and resources providing this open source code, 
+#mindsensors.com invests time and resources providing this open source code,
 #please support mindsensors.com  by purchasing products from mindsensors.com!
 #Learn more product option visit us @  http://www.mindsensors.com/
 #
 # History:
 # Date              Author          Comments
 # July 2016         Roman Bohuk     Initial Authoring
-# December 2016     Roman Bohuk     A few bugfixes (ability to rename files, bug reporting function) 
+# December 2016     Roman Bohuk     A few bugfixes (ability to rename files, bug reporting function)
+# May 2017     Seth Tenembaum  Remove login requirement
 */
 
 include "api/config.php";
 
-if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
-    header('Location: ./login.php');
-    exit();
-}
-
 ?><!DOCTYPE html>
 <html>
 <head>
@@ -58,7 +54,7 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
     }
   </style>
   <style type="text/css" media="screen">
-    #blocklyeditor, #aceeditor { 
+    #blocklyeditor, #aceeditor {
         position: absolute;
         top: 0;
         right: 0;
@@ -69,7 +65,7 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
     td {
         vertical-align: middle !important;
     }
-    
+
     @media (max-width: 600px) {
         .blocklyeditor-row, .aceeditor-row {
             padding-right:30px;
@@ -97,14 +93,6 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
         <span class="icon-bar"></span>
         <span class="icon-bar"></span>
       </a>
-
-      <div class="navbar-custom-menu">
-        <ul class="nav navbar-nav">
-          <li>
-            <a href="./logout.php">Logout&nbsp;&nbsp;<i class="fa fa-sign-out"></i></a>
-          </li>
-        </ul>
-      </div>
     </nav>
   </header>
 
@@ -113,7 +101,7 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
   ?>
 
   <div class="content-wrapper">
-  
+
     <section class="content">
       <div class="row">
         <div class="col-md-6 col-lg-4">
@@ -131,7 +119,7 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
             </div>
           </div>
         </div>
-        
+
         <div class="col-md-6 col-lg-8" id="editorDash">
           <div class="box box-danger" style="margin-bottom:0px !important;padding-bottom:0px !important;">
             <div class="box-body" id="edit_options">
@@ -153,7 +141,7 @@ if (!isset($_SESSION['logged_in']) || !$_SESSION['logged_in']) {
             </div>
           </div>
         </div>
-        
+
       </div>
 
     </section>
@@ -304,11 +292,11 @@ var editor = ace.edit("aceeditor");
 editor.setTheme("ace/theme/monokai");
 editor.getSession().setMode("ace/mode/python");
 editor.setOptions({
-   autoScrollEditorIntoView: true 
+   autoScrollEditorIntoView: true
 });
 var workspace = null;
 
-      
+
 var edittype = "";
 
 function blocklyedit(filename, location, id, content) {
@@ -376,7 +364,7 @@ function save(location) {
         var blocks = Base64.encode(xml_code);
         var code = Blockly.Python.workspaceToCode(workspace);
         content = '#!/usr/bin/env python\n\n# ATTENTION!\n# Please do not manually edit the contents of this file\n# Only use the web interface for editing\n# Otherwise, the file may no longer be editable using the web interface, or you changes may be lost\n' + copyright + '\n"""\n--BLOCKLY FILE--\n--START BLOCKS--\n' + blocks + '\n' + CryptoJS.SHA256(blocks).toString() + '\n--END BLOCKS--\n"""\n\n\n' + code;
-        
+
     } else if (edittype == "py") {
         content = editor.getValue();
     }
@@ -384,7 +372,7 @@ function save(location) {
         notify("Saved","File successfully saved","success");
         fetchlist();
     });
-    
+
 }
 
 function deleteFile(id) {
@@ -607,7 +595,7 @@ function isInteger(str) {
 function createobject() {
     var typein = $("#filetypeinput").val();
     var namein = $("#filenameinput").val();
-    
+
     var grievances = [];
     for (var i = 0; i < progs.length; i++) {
         if (progs[i][0].toLowerCase() == namein.toLowerCase() || progs[i][0].toLowerCase() == namein.toLowerCase()+".py") {
@@ -632,7 +620,7 @@ function createobject() {
     if (legal.indexOf(namein.charAt(namein.length - 1)) < 0) {
         grievances.push("The filename cannot end with a special character!");
     }
-    
+
     if (grievances.length <= 0) {
         $.post(api+"addobject", {path: currentdir, type:typein, filename:namein}, function(result){
             notify("Success","Object successfully created","success");
@@ -695,7 +683,7 @@ function renameobject() {
     if (legal.indexOf(namein.charAt(namein.length - 1)) < 0) {
         grievances.push("The filename cannot end with a special character!");
     }
-    
+
     if (grievances.length <= 0) {
         console.log({path: currentdir, filename:nameinold, filenamenew:namein + end});
         $.post(api+"renameobject", {path: currentdir, filename:nameinold, filenamenew:namein + end}, function(result){
